import React, { useMemo } from 'react';
import { ScrollView } from 'react-native';
import { defaultHTMLElementModels } from 'react-native-render-html';
import computeColumnWidths from './helpers/computeColumnWidths';
import createRenderTree from './helpers/createRenderTree';
import fillTableDisplay, { createEmptyDisplay } from './helpers/fillTableDisplay';
import RenderTree from './RenderTree';

function useRenderTree({
  tnode,
  contentWidth
}) {
  return useMemo(() => {
    const display = createEmptyDisplay();
    fillTableDisplay(tnode, display);
    const columnWidths = computeColumnWidths(display, contentWidth);
    return createRenderTree(display, columnWidths);
  }, [tnode, contentWidth]);
}

/**
 * The renderer component for `table` tag.
 *
 * @param props - Component props.
 * @public
 */
const RenderTable = function ({
  TDefaultRenderer,
  ...props
}) {
  const {
    contentWidth,
    renderersProps: {
      table
    }
  } = props.sharedProps;
  const tree = useRenderTree({
    tnode: props.tnode,
    contentWidth
  });
  return /*#__PURE__*/React.createElement(TDefaultRenderer, props, /*#__PURE__*/React.createElement(ScrollView, {
    horizontal: true,
    style: {
      width: contentWidth
    }
  }, /*#__PURE__*/React.createElement(RenderTree, {
    node: tree,
    config: table
  })));
};

RenderTable.model = defaultHTMLElementModels.table;
export default RenderTable;
//# sourceMappingURL=RenderTable.js.map