import React from 'react';
import { StyleSheet, View } from 'react-native';
import { TNodeRenderer } from 'react-native-render-html';
const styles = StyleSheet.create({
  colContainer: {
    flexDirection: 'column',
    flexGrow: 1
  },
  rowContainer: {
    flexDirection: 'row',
    flexGrow: 1
  }
});
export default function RenderTree({
  node,
  config
}) {
  if (node.type === 'cell') {
    const {
      width
    } = node;
    const style = {
      width,
      flexGrow: 1
    };
    return /*#__PURE__*/React.createElement(View, {
      style: style
    }, /*#__PURE__*/React.createElement(TNodeRenderer, {
      propsFromParent: {
        cell: node,
        collapsedMarginTop: null,
        config
      },
      parentMarkers: {},
      tnode: node.tnode
    }));
  }

  if (node.type === 'root' || node.type === 'col-container') {
    const children = node.children.map((v, i) => /*#__PURE__*/React.createElement(RenderTree, {
      node: v,
      key: i,
      config
    }));
    return /*#__PURE__*/React.createElement(View, {
      style: styles.colContainer
    }, children);
  }

  if (node.type === 'row-container') {
    return /*#__PURE__*/React.createElement(View, {
      style: styles.rowContainer
    }, node.children.map((v, i) => /*#__PURE__*/React.createElement(RenderTree, {
      node: v,
      key: i,
      config
    })));
  }

  return null;
}
//# sourceMappingURL=RenderTree.js.map