import pick from 'ramda/src/pick';
import pipe from 'ramda/src/pipe';
import sum from 'ramda/src/sum';
import map from 'ramda/src/map';
import values from 'ramda/src/values';
import multiply from 'ramda/src/multiply';
import { TText } from '@native-html/transient-render-engine';
const fontWeightCoeffs = {
  '100': 0.8,
  '200': 0.85,
  '300': 0.9,
  '400': 1,
  '500': 1.1,
  '600': 1.2,
  '700': 1.3,
  '800': 1.4,
  '900': 1.5,
  bold: 1.3,
  normal: 1
};

function toNumber(value) {
  if (typeof value === 'number') {
    return value;
  }

  return 0;
}

const hspacingFields = ['borderLeftWidth', 'borderRightWidth', 'marginLeft', 'marginRight', 'paddingLeft', 'paddingRight'];
/**
 * 14ddp = 1wg
 */

const WEIGHT_U = 14;
const computeHzWeight = pipe(pick(hspacingFields), values, map(toNumber), sum, multiply(1 / WEIGHT_U));
export default function computeTNodeWeight(tnode) {
  const hspaceWeight = computeHzWeight(tnode.styles.nativeBlockRet);

  if (tnode instanceof TText) {
    var _tnode$styles$nativeT, _tnode$styles$nativeT2, _fontWeightCoeffs$fon;

    const fontSize = (_tnode$styles$nativeT = tnode.styles.nativeTextFlow.fontSize) !== null && _tnode$styles$nativeT !== void 0 ? _tnode$styles$nativeT : WEIGHT_U;
    const fontWeight = (_tnode$styles$nativeT2 = tnode.styles.nativeTextFlow.fontWeight) !== null && _tnode$styles$nativeT2 !== void 0 ? _tnode$styles$nativeT2 : 'normal';
    const fontWeightCoeff = (_fontWeightCoeffs$fon = fontWeightCoeffs[fontWeight]) !== null && _fontWeightCoeffs$fon !== void 0 ? _fontWeightCoeffs$fon : 1;
    return (tnode.data.length + 1) * fontSize / WEIGHT_U * fontWeightCoeff + hspaceWeight;
  }

  return hspaceWeight + tnode.children.reduce((prev, curr) => computeTNodeWeight(curr) + prev, 0);
}
//# sourceMappingURL=computeTNodeWeight.js.map