import { CustomBlockRenderer } from 'react-native-render-html';
import { TNode } from 'react-native-render-html';
import { ViewStyle } from 'react-native';

/**
 * @public
 */
export declare interface CellProperties extends Coordinates {
    lenX: number;
    lenY: number;
    weight: number;
}

/**
 * @public
 */
export declare interface Coordinates {
    x: number;
    y: number;
}

/**
 * @public
 */
export declare interface DisplayCell extends CellProperties {
    tnode: TNode;
}

/**
 * Options to customize this plugin renderers.
 *
 * @public
 */
export declare interface HeuristicTablePluginConfig {
    /**
     * Customize cells appearance with this function.
     *
     * @param cell - The cell for which styles should be provided.
     */
    getStyleForCell?(cell: TableCell): ViewStyle | null;
}

/**
 * Renderers to be merged in the `renderers` prop of `RenderHTML` component.
 *
 * @public
 */
declare const renderers: Record<'th' | 'td' | 'table', CustomBlockRenderer>;
export default renderers;

/**
 * A cell is a unit of display for one `th` or `td` in a table, with
 * coordinates and lengths relative to the matrix (rows, columns) coordinate
 * system.
 *
 * <pre>
 * 0 1 2 → x
 * 1 . .
 * 2 . .
 * ↓ y
 * </pre>
 *
 * @remarks
 *
 * @public
 */
export declare interface TableCell extends DisplayCell {
    type: 'cell';
    width: number;
}

export { }
